@@ -677,10 +677,12 @@ class Transaction(object):
         if exc is None or value is None or tb is None:
             return
 
-        # 'should_ignore' is a tri-state variable with the following behavior.
-        # 'True' - ignore the error.
-        # 'False'- record the error.
-        # 'None' - Use the default ignore rules.
+        # Where ignore_errors is a callable it should return a
+        # tri-state variable with the following behavior.
+        #
+        #   True - Ignore the error.
+        #   False- Record the error.
+        #   None - Use the default ignore rules.
 
         should_ignore = None
 
@@ -737,11 +739,17 @@ class Transaction(object):
         if len(self._errors) >= settings.agent_limits.errors_per_transaction:
             return
 
-        if params:
-            custom_params = dict(self._custom_params)
-            custom_params.update(params)
+        # Only add params if High Security Mode is off.
+
+        if settings.high_security:
+            custom_params = {}
+
         else:
-            custom_params = self._custom_params
+            if params:
+                custom_params = dict(self._custom_params)
+                custom_params.update(params)
+            else:
+                custom_params = self._custom_params
 
         exc_type = exc.__name__
 
@@ -864,7 +872,10 @@ class Transaction(object):
         self._cpu_user_time_end = os.times()[0]
 
     def add_custom_parameter(self, name, value):
-        self._custom_params[name] = value
+        settings = self._settings
+
+        if not settings.high_security:
+            self._custom_params[name] = value
 
     def add_custom_parameters(self, items):
         for name, value in items:
